@@ -1,7 +1,7 @@
 use plotters::prelude::*;
 
 fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let mut img = BitMapBackend::new("/tmp/plotter.png", (1024, 768));
+    let mut img = BitMapBackend::new("examples/outputs/sample.png", (1024, 768));
 
     img.open()?;
 
@@ -13,7 +13,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let font_large = &font.resize(60.0);
     let font_small = &font.resize(40.0);
     let root_area = root_area
-        .titled("Hello World!", &font_large)?
+        .titled("Image Title", &font_large)?
         .margin(0, 0, 0, 20);
 
     let (upper, lower) = root_area.split_vertically(512);
@@ -27,15 +27,17 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     cc.configure_mesh()
         .x_labels(20)
         .y_labels(10)
+        .disable_x_mesh()
+        .disable_y_mesh()
         .x_label_formatter(&|v| format!("{:.1}", v))
         .y_label_formatter(&|v| format!("{:.1}", v))
         .draw()?;
 
-    cc.define_series_label_area(
+    /*cc.define_series_label_area(
         (720, 130),
         (240, 100),
         Into::<ShapeStyle>::into(&RGBColor(255, 255, 255).mix(0.7)).filled(),
-    )?;
+    )?;*/
 
     cc.draw_series(LineSeries::new(
         (0..12).map(|x| ((x - 6) as f32 / 2.0, ((x - 6) as f32 / 2.0).sin())),
@@ -59,6 +61,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         5,
         Into::<ShapeStyle>::into(&RGBColor(255,0,0)).filled(),
     ))?;*/
+
     let point_font = font_small.resize(15.0);
     // Otherwise you can use a function to construct your pointing element yourself
     cc.draw_series(PointSeries::of_element(
@@ -78,9 +81,19 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         let mut cc = ChartBuilder::on(&drawing_area)
             .set_x_label_size(50)
             .set_y_label_size(60)
-            .caption(format!("Chart {}", idx), &font_large)
-            .build_ranged::<RangedCoordf32, RangedCoordf32, _, _>(0f32..11f32, 0f32..11f32);
-        cc.configure_mesh().x_labels(5).y_labels(5).draw()?
+            .caption(format!("y = x^{}", 1 + 2 * idx), &font_small)
+            .build_ranged::<RangedCoordf32, RangedCoordf32, _, _>(-1f32..1f32, -1f32..1f32);
+        cc.configure_mesh().x_labels(5).y_labels(5).draw()?;
+
+        cc.draw_series(LineSeries::new(
+            (-100..100).map(|x| {
+                (
+                    x as f32 / 100.0,
+                    (x as f32 / 100.0).powf(idx as f32 * 2.0 + 1.0),
+                )
+            }),
+            &RGBColor(0, 0, 255),
+        ))?;
     }
 
     root_area.close()?;
