@@ -12,9 +12,10 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         .caption("Histogram Test", &font)
         .build_ranged::<RangedCoordu32, RangedCoordu32, _, _>(0..10, 0..10);
 
-    chart.configure_mesh()
+    chart
+        .configure_mesh()
         .disable_x_mesh()
-        .line_style_1(&Into::into(&RGBColor(255,255,255).mix(0.3)))
+        .line_style_1(&Into::into(&RGBColor(255, 255, 255).mix(0.3)))
         .x_label_offset(30)
         .draw()?;
 
